#
# spec file for package python-intake
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-intake
Version:        0.5.4
Release:        2.1
Summary:        Data loading and cataloging system
License:        BSD-2-Clause
URL:            https://github.com/ContinuumIO/intake
Source0:        https://files.pythonhosted.org/packages/source/i/intake/intake-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-PyYAML
Requires:       python-appdirs
Requires:       python-dask
Requires:       python-dask-array
Requires:       python-dask-bag >= 1.0
Requires:       python-dask-dataframe
Requires:       python-entrypoints
Requires:       python-fsspec >= 0.3.6
Requires:       python-holoviews
Requires:       python-hvplot
Requires:       python-ipywidgets >= 7.2
Requires:       python-msgpack
Requires:       python-msgpack-numpy
Requires:       python-numpy
Requires:       python-pandas
Requires:       python-pytest
Requires:       python-python-snappy
Requires:       python-requests
Requires:       python-ruamel.yaml >= 0.15.0
Requires:       python-six
Requires:       python-tornado >= 4.5.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module dask-bag >= 1.0}
BuildRequires:  %{python_module dask-dataframe}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module entrypoints}
BuildRequires:  %{python_module fsspec >= 0.3.6}
BuildRequires:  %{python_module holoviews}
BuildRequires:  %{python_module hvplot}
BuildRequires:  %{python_module ipywidgets >= 7.2}
BuildRequires:  %{python_module msgpack-numpy}
BuildRequires:  %{python_module msgpack}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-snappy}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module ruamel.yaml >= 0.15.0}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module tornado >= 4.5.1}
# /SECTION
%python_subpackages

%description
A plugin system for loading your data and making data catalogs.

%prep
%setup -q -n intake-%{version}
sed -i -e '/^#!\//, 1d' intake/catalog/tests/test_persist.py
sed -i -e '/^#!\//, 1d' intake/container/tests/__init__.py
sed -i -e '/^#!\//, 1d' intake/container/tests/test_generics.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/intake
%python_clone -a %{buildroot}%{_bindir}/intake-server
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/intake/cli/tests/
%python_expand $python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/intake/cli/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}/intake/cli/tests/

%post
%python_install_alternative intake
%python_install_alternative intake-server

%postun
%python_uninstall_alternative intake
%python_uninstall_alternative intake-server

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/intake-server
%python_alternative %{_bindir}/intake
%{python_sitelib}/*

%changelog
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.4
  * Allow for hvplot returning dynamic layouts
  * Make sure that ttl is numeric
  * add intake-nested-yaml-catalog plugin
  * check_meta_flag -> verify_meta
  * forgot to add pickle & json
  * fix dask version constraint
  * Don't replace "inteke" in remote server name
  * Update intake/gui/source/defined_plots.py
  * Use a generator for pagination.
  * add address to log
  * add server cli kwarg for address
  * dask.bytes to fsspec
  * don't check meta when merging dataframes
  * pin fsspec >= 0.3.6
  * return storage options if given
  * update open_file link
  * use the given encoder if not in the list
  * verify kwarg and dask version check
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.3
  * use frombuffer (fromstring is depr)
  * fix npy source
  * make example using storge_options usable
  * update docs around storage_options
  * Don't necessarily pass storage_options
  * fix with test
  * Add setup entrypoints for drivers and tidy CLI
  * Don't warn twice
  * Add drivers CLI test
  * update test
  * Add a load of tests
  * Fix msgpack imports so msgpack_numpy is not required.
  * ian-r-rose committed on Jul 26
  * Use master dask on pip build too
  * Don't import msgpack_numpy unless needed
  * prefer conda-forge for installs
  * Add constructor for tuples during safe load
  * Fixes on URLs
  * one remaining dask.bytes
  * Test basic passing on of filesystems
  * Pass filesystem stuff through
  * Merge branch 'master' into fs
  * Remove unused import.
  * Refine temp_config_path fixutre.
  * Improve test coverage of discovery.
  * Fix name error exposed by testing.
  * Fix log call missing msg arg.
  * Fix typo.
  * Issue PendingDeprecationWarning for do_package_scan.
  * Document that do_package_scan will be changed and then removed.
  * Remove __future__ imports.
  * wget syntax
  * much simpler travis script
  * simple build
  * deps
  * simplify travis installs
  * fix up
  * Merge branch 'master' into fs
  * replace dask.bytes imports
  * Fix typo --- intended length check.
  * Add autodiscover_all and list non-enabled plugins.
  * Add module docstring.
  * Look for and log entrypoint name collision.
  * Fix typo (local var name changed).
  * Document interaction between package scan and entrypoint.
  * Use 'raise from'.
  * Issue FutureWarning for any package_scan_results.
  * Fix typos.
  * Include module in debug log messages.
  * Fix typo
  * Fix shadowing.
  * Add debug logs. Separate discovery and loading.
  * Remove another unused import.
  * Roll back unneeded changes.
  * Update 'Making Drivers' docs.
  * Finish conf integration; update CLI.
  * Incorporate 'drivers' section in config.
  * Make test_which more robust.
  * Incorporate 'intake.drivers' entrypoint.
  * Make enable/disable accessible from Python API.
  * Remove Python 2 compat.
  * Skip unreadable entries after logging error.
  * Remove usage of six. Use yaml_load util func.
  * Fix biffed rebase.
  * Refine help string.
  * Add drivers.d system and drivers subcommand.
  * Minor typo fix in the "Making Drivers" docs
  * move the {en|de}code_datetime to the compat.{pack|unpack}_kwargs
  * Provide ndim attribute for npy accessor
  * added test to check if datetime user_parameters work
  * add use case for upload
  * handle lack of tz info
  * add tests for coerce_datetime and handle non-iterable input
  * fix numpy warning, and future issue with elementwise comparison
  * rm errant print()
  * added {en|de}code_datetime to various msgpack.{packb|unpackb}
  * Change API
  * WIP: is this the right add source API?
  * copy is_dataframe_like
  * add to API docs
  * Add uppload function and machinery
  * explicit reference to nested cats in conda packages
  * Update talks
  * Working FS
  * Update use_cases.rst
  * fixes
  * Merge branch 'master' into params_editor
  * revert line
  * mid
  * start
  * fix tests
  * Hide plot when changing source selection
  * inatke-examples link
  * rst not md
  * Update links to intake-examples and include GUI blog
  * Refactor to make one less copy.
  * Avoid accidental mutation.
  * Storage options applied to wrong FS in compressed cache
  * Add GUI classes
  * Merge branch 'master' into more_api
  * Add classes
  * Let GUI docs be visible; don't ever error on repr
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * Making sure that catalog and entry guis work
  * Making sure that logo is always part of panel
  * A little paranoia in case describe() exposes mutable state.
  * Do not nest inside 'source' key twice.
  * Work on copy that will be serialized.
  * Apply to info-get route
  * Don't attempt to serialise functions in server response
  * Defer inputs until needed
  * add intake-stac to plugins list
  * Allow local cat entry to specify explicit driver class
  * In GUI code, use describe() rather than attrbiutes
  * make msgpack_numpy optional
  * Don't pop plots from metadata
  * Don't remove plots from description
  * Add intake-dcat to the plugin directory.
  * Serializing and deserializing state
  * Add name to describe(), standardize describe() and describe_open()
  * Fixing up done_callback switch
  * Allow the expannding and collapsing of nested catalogs
  * Disable buttons when they aren't ready
- Fix jupyter dependencies.
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
